@@ -8,6 +8,7 @@ import Test.MockCat.TypeClassSpec as TypeClass
 import Test.MockCat.TypeClassTHSpec as TypeClassTH
 import Test.MockCat.PartialMockSpec as PartialMock
 import Test.MockCat.PartialMockTHSpec as PartialMockTH
+import Test.MockCat.ConcurrencySpec as Concurrency
 
 main :: IO ()
 main = do
@@ -20,4 +21,5 @@ main = do
     TypeClass.spec
     TypeClassTH.spec
     PartialMock.spec
-    PartialMockTH.spec
\ No newline at end of file
+    PartialMockTH.spec
+    Concurrency.spec
\ No newline at end of file
